function initialize() {

	ToggleMode = {
	    TOGGLE: 0,
	    SHOW: 1,
	    HIDE: 2
	};
	
	var toggleContents = function( section, animation, mode, target )
	{
		target = target || ".sectionbody";
		
		section.each( function() {
		
			var section = $(this);
			mode = mode || ToggleMode.TOGGLE;					
			
			var button = section.find( ".button.contenttoggle" ).first();
			var body = section.find( target ).first();
			var summary = section.find( ".bar.contentssummary" ).first();
			
			if ( body.length == 0 )
			{
				body = section;
			}
			
			
			switch ( mode )
			{
				case ToggleMode.TOGGLE:
					section.toggleClass( "visible" );
					animation ? body.slideToggle( "fast" ) : body.toggle();
					if ( summary !== undefined )
					{
						animation ? summary.fadeToggle( "slow" ) : summary.toggle();
					}
					break;
				case ToggleMode.SHOW:
					section.addClass( "visible" );
					animation ? body.slideDown( "fast" ) : body.show();
					if ( summary !== undefined )
					{
						animation ? summary.fadeOut( "slow" ) : summary.hide();
					}
					break;
				case ToggleMode.HIDE:
					section.removeClass( "visible" );
					animation ? body.slideUp( "fast" ) : body.hide();
					if ( summary !== undefined )
					{
						animation ? summary.fadeIn( "slow" ) : summary.show();
					}
					break;
				
			}
			
			button.text( section.hasClass( "visible" ) ? "-" : "+" );					
			button.attr( "title", section.hasClass( "visible" ) ? "Click to collapse" : "Click to expand" );
		} );					
	};
	
	
	var createContentsToggleButtons = function() {
	
		// create button
		var sectionheaders = $( ".sectionheader" ).not( ".evidence .sectionheader, .subsubsection .sectionheader" );
		
		sectionheaders.prepend( "<span class=\"button contenttoggle\"><a>" + "-" + "</a></span>" );
		sectionheaders.parent().addClass( "visible" );
		
		var buttons = $( ".button.contenttoggle" );
		
		buttons.click( function() {
			toggleContents( $(this).parent().parent(), true, ToggleMode.TOGGLE );
		});										
	};
		   			
	var toggleAllContents = function( animation, mode ) {
		   			
		var sections = $( ".section, .subsection" ).not( ".evidence .section, .evidence .subsection, .subsubsection .sectionheader" );
							
		toggleContents( sections, animation, mode );
	}
	
	var createContentsSummaryBar = function() {
	
		// create button
		var sectionheaders = $( ".sectionheader" ).not( ".evidence .sectionheader, .meta .sectionheader, .subsubsection .sectionheader" );
		
		sectionheaders.append( "<span class=\"bar contentssummary\"></span>" );
	};
	
	
	var createEvidenceToggleButtons = function() {
	
		// create button
		var sectionheaders = $( ".evidence" );
		
		sectionheaders.prepend( "<span class=\"button evidencetoggle\"><a title=\"Click to hide details\">" + "&times;" + "</a></span>" );
		sectionheaders.addClass( "visible" );
		
		var buttons = $( ".evidence .button.evidencetoggle" );
		
		buttons.click( function() {
			toggleContents( $(this).parent(), true, ToggleMode.HIDE, ".evidence" );
			
			var resultId = $(this).parent().attr( 'id' ).split( '_' )[1];
			$( "#resultid_" + resultId ).removeClass( "active" );			
		
		});										
	};
	
	createContentsToggleButtons();
	createContentsSummaryBar();
	createEvidenceToggleButtons();
		
	$('#results .evidence').hide();
										
	var toggleEvidence = function() {
		var resultId = $(this).attr( 'id' ).split( '_' )[1];
		var evidence = $('#evidenceid_' + resultId );
		
		if ( evidence.length != 0 )
		{
			$('#results .evidence').not( evidence ).slideUp( "slow" );
			evidence.slideToggle( 'slow' );	
			$('#results .result').not( $(this) ).removeClass( "active" );
			$(this).toggleClass( 'active' );
			$(this).attr( "title", $(this).hasClass( "active" ) ? "Click to hide details" : "Click to show details" );
		}
		else
		{
			alert( "No evidence found for result \"" + resultId + "\"." );
		}
							
		return false;
	}				
	
	$('#results .result').each( function() {
		var resultId = $(this).attr( 'id' ).split( '_' )[1];
		
		if ( resultId == undefined )
		{
			$(this).addClass( "noevidence" );
		}				
	});
	
	$('#results .result').not( ".noevidence" ).click( toggleEvidence );	
					
	var overallSignificantResults = 0;
	
	$( "#results .subsection" ).not( ".evidence" ).each( function( index ) {
		var significantResults = 0;
	
		$(this).find( '.significant' ).each( function( index ) {
			++significantResults;
		});
		
		// TODO: check for unique result ids
		
		if ( significantResults > 0 )
		{
			$(this).addClass( "significant" );
			$(this).find( ".contentssummary" ).first().append( "<span class=\"summary significant\">" + significantResults + " 	significant findings</span>" );
		}
		
		overallSignificantResults += significantResults;
	} );
					
	if ( overallSignificantResults > 0 )
	{	
		$( "#results .sectionheader .contentssummary" ).not( "#results .subsection .sectionheader .contentssummary" ).html( "<span class=\"summary significant\">" + overallSignificantResults + " significant findings</span>" );
	}
	else
	{
		//$('#results #resultsheader .contentssummary').html( "<span class=\"summary\">No significant findings</span>" );
	}
	
	$('#summary #significantsummary').append( overallSignificantResults + " significant results were found." );								
	
	var scaleImage = function() {
		var width = $(this).css( 'width' );
		
		if ( width === "200px" )
		{
			$(this).animate( { 'width': "800px" }, "fast" );
			$(this).attr( "title", "Click to reduce" );
		}
		else
		{
			$(this).animate( { 'width': "200px" }, "fast" );
			$(this).attr( "title", "Click to enlarge" );
		}
							
		return false;
	}				
					
	$( '.figure .image').each( function() { 
		$(this).find( "img" ).css( "width", "200px" );
		$(this).find( "img" ).click( scaleImage );
		$(this).find( "img" ).attr( "title", "Click to enlarge" );
	});				
	
	toggleAllContents( false, ToggleMode.HIDE );	   			
	toggleContents( $( "#overview, #summary" ), false );				

}
